import { type ActorConfig, type HttpAgentOptions, type DerEncodedPublicKey, type ActorSubclass } from "@dfinity/agent";
import type { IDL } from "@dfinity/candid";
import type { SIWS_IDENTITY_SERVICE } from "./service.interface";
import type { PublicKey } from "@solana/web3.js";
/**
 * Creates an anonymous actor for interactions with the Internet Computer.
 * This is used primarily for the initial authentication process.
 */
export declare function createAnonymousActor({ idlFactory, canisterId, httpAgentOptions, actorOptions, }: {
    idlFactory: IDL.InterfaceFactory;
    canisterId: string;
    httpAgentOptions?: HttpAgentOptions;
    actorOptions?: ActorConfig;
}): ActorSubclass<SIWS_IDENTITY_SERVICE> | undefined;
export declare function callPrepareLogin(anonymousActor: ActorSubclass<SIWS_IDENTITY_SERVICE>, publicKey: PublicKey): Promise<import("./service.interface").SiwsMessage>;
/**
 * Logs in the user by sending a signed SIWS message to the backend.
 */
export declare function callLogin(anonymousActor: ActorSubclass<SIWS_IDENTITY_SERVICE>, signature: string, publicKey: PublicKey, sessionPublicKey: DerEncodedPublicKey): Promise<import("./service.interface").LoginDetails>;
/**
 * Retrieves a delegation from the backend for the current session.
 */
export declare function callGetDelegation(anonymousActor: ActorSubclass<SIWS_IDENTITY_SERVICE>, publicKey: PublicKey, sessionPublicKey: DerEncodedPublicKey, expiration: bigint): Promise<import("./service.interface").SignedDelegation>;
